# Typenum

This package provide a way to create typed enumerations.

Archive and move to [enumetyped](https://github.com/rjotanm/enumetyped), because typenum is ambiguous between TypeNum and TypEnum.
